searchData={"items":[{"type":"module","title":"CurlReq","doc":"Req is awesome, but the world speaks curl.\n\nNext time you're debugging a 3rd party API and need to ask for support, you can just toss in this line:\n\n```elixir\n|> CurlReq.inspect()\n```\n\nAnd you'll have the full curl command.\n\n[Read the announcement here](https://codecodeship.com/blog/2024-06-03-curl_req).","ref":"CurlReq.html"},{"type":"module","title":"Usage - CurlReq","doc":"","ref":"CurlReq.html#module-usage"},{"type":"module","title":"Req to Curl - CurlReq","doc":"```elixir\n# Turn a Req request into a `curl` command.\n\niex> Req.new(url: \"/fact\", base_url: \"https://catfact.ninja/\")\n...> |> CurlReq.to_curl()\n\"curl --compressed -X GET https://catfact.ninja/fact\" \n\n# Or use `CurlReq.inspect/2` to inspect inline.\n\niex> Req.new(url: \"/fact\", base_url: \"https://catfact.nijna/\")\n...> |> CurlReq.inspect(label: \"MY REQ\")\n...> # |> Req.request!()\n\n```","ref":"CurlReq.html#module-req-to-curl"},{"type":"module","title":"Curl to Req - CurlReq","doc":"`CurlReq` also implements the `~CURL` sigil, which converts a curl command to its corresponding Req request.\n\n```elixir\niex> import CurlReq\n...> ~CURL(curl https://www.google.com)\n...> # |> Req.request!()\n\n```\n\nor use `CurlReq.from_curl/1`:\n```elixir\niex> CurlReq.from_curl(\"curl https://www.google.com\")\n...> # |> Req.request!()\n\n```","ref":"CurlReq.html#module-curl-to-req"},{"type":"module","title":"Req Plugin - CurlReq","doc":"One final feature to note the Req plugin, `CurlReq.Plugin`. Use `CurlReq.Plugin.attach/2` to set up curl logging (inspired by `TeslaCurl`).\n\n```elixir\niex> Req.new(url: \"/fact\", base_url: \"https://catfact.ninja/\")\n...> |> CurlReq.Plugin.attach()\n...> # |> Req.request!()\n\n```","ref":"CurlReq.html#module-req-plugin"},{"type":"function","title":"CurlReq.from_curl/1","doc":"Transforms a curl command into a Req request.\n\nSupported curl command line flags are supported:\n\n* `-H`/`--header`\n* `-X`/`--request`\n* `-d`/`--data`\n* `-b`/`--cookie`\n* `-I`/`--head`\n* `-F`/`--form`\n* `-L`/`--location`\n* `-u`/`--user`\n* `--compressed`\n\nThe `curl` command prefix is optional\n\n> #### Info {: .info}\n>\n> Only string inputs are supported. That means for example `-d @data.txt` will not load the file or `-d @-` will not read from stdin","ref":"CurlReq.html#from_curl/1"},{"type":"function","title":"Examples - CurlReq.from_curl/1","doc":"iex> CurlReq.from_curl(\"curl https://www.google.com\")\n    %Req.Request{method: :get, url: URI.parse(\"https://www.google.com\")}\n\n    iex> ~S(curl -d \"some data\" https://example.com) |> CurlReq.from_curl()\n    %Req.Request{method: :get, body: \"some data\", url: URI.parse(\"https://example.com\")}\n\n    iex> CurlReq.from_curl(\"curl -I https://example.com\")\n    %Req.Request{method: :head, url: URI.parse(\"https://example.com\")}\n\n    iex> CurlReq.from_curl(\"curl -b cookie_key=cookie_val https://example.com\")\n    %Req.Request{method: :get, headers: %{\"cookie\" => [\"cookie_key=cookie_val\"]}, url: URI.parse(\"https://example.com\")}","ref":"CurlReq.html#from_curl/1-examples"},{"type":"function","title":"CurlReq.inspect/2","doc":"Inspect a Req struct in curl syntax.\n\nReturns the unchanged `req`, just like `IO.inspect/2`.","ref":"CurlReq.html#inspect/2"},{"type":"function","title":"Examples - CurlReq.inspect/2","doc":"iex> Req.new(url: URI.parse(\"https://www.google.com\"))\n    ...> |> CurlReq.inspect()\n    ...> # |> Req.request!()","ref":"CurlReq.html#inspect/2-examples"},{"type":"macro","title":"CurlReq.sigil_CURL/2","doc":"Same as `from_curl/1` but as a sigil. The benefit here is, that the Req.Request struct will be created at compile time and you don't need to escape the string","ref":"CurlReq.html#sigil_CURL/2"},{"type":"macro","title":"Examples - CurlReq.sigil_CURL/2","doc":"iex> import CurlReq\n    ...> ~CURL(curl \"https://www.google.com\")\n    %Req.Request{method: :get, url: URI.parse(\"https://www.google.com\")}\n\n    iex> import CurlReq\n    ...> ~CURL(curl -d \"some data\" \"https://example.com\")\n    %Req.Request{method: :get, body: \"some data\", url: URI.parse(\"https://example.com\")}\n\n    iex> import CurlReq\n    ...> ~CURL(curl -I \"https://example.com\")\n    %Req.Request{method: :head, url: URI.parse(\"https://example.com\")}\n\n    iex> import CurlReq\n    ...> ~CURL(curl -b \"cookie_key=cookie_val\" \"https://example.com\")\n    %Req.Request{method: :get, headers: %{\"cookie\" => [\"cookie_key=cookie_val\"]}, url: URI.parse(\"https://example.com\")}","ref":"CurlReq.html#sigil_CURL/2-examples"},{"type":"function","title":"CurlReq.to_curl/2","doc":"Transforms a Req request into a curl command.\n\nSupported curl flags are:\n\n* `-b`/`--cookie`\n* `-H`/`--header`\n* `-X`/`--request`\n* `-L`/`--location`\n* `-I`/`--head`\n* `-d`/`--data`/`--data-ascii`\n* `--data-raw`\n\nOptions:\n\n- `run_steps`: Run the Req.Steps before generating the curl command. Default: `true`. This option is semi-private, introduced to support CurlReq.Plugin.\n- `flags`: Specify the style the argument flags are constructed. Can either be `:short` or `:long`, Default: `:short`\n- `flavor` or `flavour`: With the `:curl` flavor (the default) it will try to use native curl representations for compression, auth and will use the native user agent. \nIf flavor is set to `:req` the headers will not be modified and the curl command is constructed to stay as true as possible to the original `Req.Request`","ref":"CurlReq.html#to_curl/2"},{"type":"function","title":"Examples - CurlReq.to_curl/2","doc":"iex> Req.new(url: URI.parse(\"https://www.google.com\"))\n    ...> |> CurlReq.to_curl()\n    ~S(curl --compressed -X GET https://www.google.com)\n\n    iex> Req.new(url: URI.parse(\"https://www.google.com\"))\n    ...> |> CurlReq.to_curl(flags: :long, flavor: :req)\n    ~S(curl --header \"accept-encoding: gzip\" --header \"user-agent: req/0.5.0\" --request GET https://www.google.com)","ref":"CurlReq.html#to_curl/2-examples"},{"type":"type","title":"CurlReq.flags/0","doc":"","ref":"CurlReq.html#t:flags/0"},{"type":"type","title":"CurlReq.flavor/0","doc":"","ref":"CurlReq.html#t:flavor/0"},{"type":"type","title":"CurlReq.inspect_opt/0","doc":"","ref":"CurlReq.html#t:inspect_opt/0"},{"type":"type","title":"CurlReq.to_curl_opts/0","doc":"","ref":"CurlReq.html#t:to_curl_opts/0"},{"type":"module","title":"CurlReq.Plugin","doc":"A collection of steps, usable with Req.\n\n> #### Info {: .info}\n>\n> This plugin needs to be added behind any other Req.Steps. Steps add headers and change the request, and this all has to be done _before_ converting the request to a curl command.","ref":"CurlReq.Plugin.html"},{"type":"module","title":"Examples - CurlReq.Plugin","doc":"iex> Req.new(url: \"https://catfact.ninja/fact\")\n    ...> |>CurlReq.Plugin.attach()\n\n    iex> Req.new(url: \"https://catfact.ninja/fact\")\n    ...> |> CurlReq.Plugin.attach(log_level: :info, log_metadata: [ansi_color: :blue])\n\n# Possible improvements\n\nThis module could be improved. PRs are welcome!\n\n- [ ] configure redaction on a per-header basis\n\nSee also [TeslaCurl](https://hexdocs.pm/tesla_curl/readme.html) for inspiration.","ref":"CurlReq.Plugin.html#module-examples"},{"type":"function","title":"CurlReq.Plugin.attach/2","doc":"Attaches the plugin, main entry point for this module.","ref":"CurlReq.Plugin.html#attach/2"},{"type":"function","title":"CurlReq.Plugin.log/1","doc":"Req step: logs the request.","ref":"CurlReq.Plugin.html#log/1"},{"type":"type","title":"CurlReq.Plugin.option/0","doc":"","ref":"CurlReq.Plugin.html#t:option/0"}],"content_type":"text/markdown","producer":{"name":"ex_doc","version":[48,46,51,52,46,48]}}